install_hash_table_lib

Function install_hash_table_lib 

pub fn install_hash_table_lib(cx: &mut Cx) -> Result<()>
Register the HashBackend and load the HashTableLib into cx.

Idempotent: if the table/hash library is already present the call is a no-op. After installation the hash backend can be selected as the active table backend via the context table registry.